"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const BrowserlessDescriptions_1 = require("../BrowserlessDescriptions");
const browserless_api_schema_1 = require("../chemas/browserless-api.schema");
const GenericFunctions_1 = require("../GenericFunctions");
(0, globals_1.describe)('parseFixedCollectionOptions', () => {
    (0, globals_1.it)('should parse cookies as an array', () => {
        const collectionOptions = {
            cookies: { cookies: [{ name: 'Test', value: 'test' }] },
        };
        const parsedFixedCollectionOptions = (0, GenericFunctions_1.parseCollectionOptions)(BrowserlessDescriptions_1.browserlessPageOptionsFileds, collectionOptions);
        console.log('----', parsedFixedCollectionOptions);
        const results = browserless_api_schema_1.content.validate({
            url: 'https://google.com',
            ...parsedFixedCollectionOptions,
        });
        (0, globals_1.expect)(results.error).toBeUndefined();
    });
    (0, globals_1.it)('should parse header as an object', () => {
        const collectionOptions = {
            setExtraHTTPHeaders: { header: { name: 'Test', value: 'test' } },
        };
        const parsedFixedCollectionOptions = (0, GenericFunctions_1.parseCollectionOptions)(BrowserlessDescriptions_1.browserlessPageOptionsFileds, collectionOptions);
        console.log('----', parsedFixedCollectionOptions);
        const results = browserless_api_schema_1.content.validate({
            url: 'https://google.com',
            ...parsedFixedCollectionOptions,
        });
        (0, globals_1.expect)(results.error).toBeUndefined();
    });
    (0, globals_1.it)('should parse authenticate properly', () => {
        const collectionOptions = {
            authenticate: { authenticate: { username: 'Test', password: 'test' } },
        };
        const parsedFixedCollectionOptions = (0, GenericFunctions_1.parseCollectionOptions)(BrowserlessDescriptions_1.browserlessPageOptionsFileds, collectionOptions);
        console.log('----', parsedFixedCollectionOptions);
        const results = browserless_api_schema_1.content.validate({
            url: 'https://google.com',
            ...parsedFixedCollectionOptions,
        });
        (0, globals_1.expect)(results.error).toBeUndefined();
    });
    (0, globals_1.it)('should parse goto options properly', () => {
        const collectionOptions = {
            gotoOptions: {
                gotoOptions: {
                    timeout: 0,
                    waitUntil: 'load',
                },
            },
        };
        const parsedFixedCollectionOptions = (0, GenericFunctions_1.parseCollectionOptions)(BrowserlessDescriptions_1.browserlessPageOptionsFileds, collectionOptions);
        console.log('----', parsedFixedCollectionOptions);
        const results = browserless_api_schema_1.content.validate({
            url: 'https://google.com',
            ...parsedFixedCollectionOptions,
        });
        (0, globals_1.expect)(results.error).toBeUndefined();
        (0, globals_1.expect)(results.value).toMatchSnapshot({
            gotoOptions: {
                timeout: 0,
                waitUntil: 'load',
            },
        });
    });
});
//# sourceMappingURL=GenericFunctions.test.js.map