"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.stats = exports.fn = exports.scrape = exports.pdf = exports.content = exports.screenshot = void 0;
const joi_1 = __importDefault(require("joi"));
const waitFor = [joi_1.default.string(), joi_1.default.number()];
const userAgent = joi_1.default.string();
const gotoOptions = joi_1.default.object().keys({
    timeout: joi_1.default.number(),
    waitUntil: joi_1.default.string().valid('load', 'domcontentloaded', 'networkidle0', 'networkidle2'),
});
const authenticate = joi_1.default.object().keys({
    password: joi_1.default.string(),
    username: joi_1.default.string(),
});
const setExtraHTTPHeaders = joi_1.default.object().unknown();
const setJavaScriptEnabled = joi_1.default.boolean();
const rejectRequestPattern = joi_1.default.array().items(joi_1.default.string()).default([]);
const rejectResourceTypes = joi_1.default.array()
    .items(joi_1.default.string().valid('document', 'stylesheet', 'image', 'media', 'font', 'script', 'texttrack', 'xhr', 'fetch', 'eventsource', 'websocket', 'manifest', 'other'))
    .default([]);
const addScriptTag = joi_1.default.array()
    .items(joi_1.default.object().keys({
    url: joi_1.default.string().allow('').optional(),
    content: joi_1.default.string().allow('').optional(),
    type: joi_1.default.string().allow('').optional(),
}))
    .default([]);
const addStyleTag = joi_1.default.array()
    .items(joi_1.default.object().keys({
    url: joi_1.default.string().allow('').optional(),
    content: joi_1.default.string().allow('').optional(),
}))
    .default([]);
const requestInterceptors = joi_1.default.array()
    .items(joi_1.default.object().keys({
    pattern: joi_1.default.string().required(),
    response: joi_1.default.object().keys({
        body: joi_1.default.alternatives([joi_1.default.string(), joi_1.default.binary()]).required(),
        contentType: joi_1.default.string().required(),
        headers: joi_1.default.object(),
        status: joi_1.default.number().required(),
    }),
}))
    .default([]);
const cookies = joi_1.default.array()
    .items(joi_1.default.object({
    domain: joi_1.default.string(),
    expires: joi_1.default.number().min(0),
    httpOnly: joi_1.default.boolean(),
    name: joi_1.default.string().required(),
    path: joi_1.default.string(),
    sameSite: joi_1.default.string().valid('Strict', 'Lax'),
    secure: joi_1.default.boolean(),
    url: joi_1.default.string(),
    value: joi_1.default.string().required(),
}))
    .default([]);
const viewport = joi_1.default.object().keys({
    deviceScaleFactor: joi_1.default.number().min(0.01).max(100),
    hasTouch: joi_1.default.boolean(),
    height: joi_1.default.number().min(0).required(),
    isLandscape: joi_1.default.boolean(),
    isMobile: joi_1.default.boolean(),
    width: joi_1.default.number().min(0).required(),
});
exports.screenshot = joi_1.default.object()
    .keys({
    authenticate,
    addScriptTag,
    addStyleTag,
    cookies,
    gotoOptions,
    html: joi_1.default.string(),
    manipulate: joi_1.default.object().keys({
        resize: joi_1.default.object().keys({
            width: joi_1.default.number().integer().positive(),
            height: joi_1.default.number().integer().positive(),
            fit: joi_1.default.string().valid('cover', 'contain', 'fill', 'inside', 'outside'),
            position: joi_1.default.string().valid('top', 'right top', 'right', 'right bottom', 'bottom', 'left bottom', 'left', 'left top'),
        }),
        flip: joi_1.default.boolean(),
        flop: joi_1.default.boolean(),
        rotate: joi_1.default.number(),
    }),
    options: joi_1.default.object().keys({
        clip: joi_1.default.object().keys({
            height: joi_1.default.number().min(0),
            width: joi_1.default.number().min(0),
            x: joi_1.default.number().min(0),
            y: joi_1.default.number().min(0),
        }),
        fullPage: joi_1.default.boolean(),
        omitBackground: joi_1.default.boolean(),
        quality: joi_1.default.number().min(0).max(100),
        type: joi_1.default.string().valid('jpeg', 'png'),
        encoding: joi_1.default.string().valid('binary', 'base64'),
    }),
    rejectRequestPattern,
    rejectResourceTypes,
    requestInterceptors,
    scrollPage: joi_1.default.boolean(),
    selector: joi_1.default.string(),
    setExtraHTTPHeaders,
    setJavaScriptEnabled,
    url: joi_1.default.string(),
    userAgent,
    viewport,
    waitFor,
})
    .xor('url', 'html');
exports.content = joi_1.default.object().keys({
    authenticate,
    addScriptTag,
    addStyleTag,
    cookies,
    gotoOptions,
    rejectRequestPattern,
    rejectResourceTypes,
    requestInterceptors,
    setExtraHTTPHeaders,
    setJavaScriptEnabled,
    url: joi_1.default.string().required(),
    userAgent,
    viewport,
    waitFor,
});
exports.pdf = joi_1.default.object()
    .keys({
    authenticate,
    addScriptTag,
    addStyleTag,
    cookies,
    emulateMedia: joi_1.default.string().valid('screen', 'print'),
    gotoOptions,
    html: joi_1.default.string(),
    options: joi_1.default.object().keys({
        displayHeaderFooter: joi_1.default.boolean(),
        footerTemplate: joi_1.default.string(),
        format: joi_1.default.string().valid('Letter', 'Legal', 'Tabloid', 'Ledger', 'A0', 'A1', 'A2', 'A3', 'A4', 'A5', 'A6'),
        headerTemplate: joi_1.default.string(),
        height: joi_1.default.any().optional(),
        landscape: joi_1.default.boolean(),
        margin: joi_1.default.object().keys({
            bottom: joi_1.default.string(),
            left: joi_1.default.string(),
            right: joi_1.default.string(),
            top: joi_1.default.string(),
        }),
        pageRanges: joi_1.default.string(),
        preferCSSPageSize: joi_1.default.boolean(),
        printBackground: joi_1.default.boolean(),
        scale: joi_1.default.number().min(0),
        width: joi_1.default.any().optional(),
        omitBackground: joi_1.default.boolean(),
        timeout: joi_1.default.number(),
    }),
    rejectRequestPattern,
    rejectResourceTypes,
    requestInterceptors,
    rotate: joi_1.default.number().valid(90, -90, 180),
    safeMode: joi_1.default.boolean().default(false),
    setExtraHTTPHeaders,
    setJavaScriptEnabled,
    url: joi_1.default.string(),
    userAgent,
    viewport,
    waitFor,
})
    .xor('url', 'html');
exports.scrape = joi_1.default.object().keys({
    authenticate,
    addScriptTag,
    addStyleTag,
    cookies,
    debug: joi_1.default.object().keys({
        console: joi_1.default.boolean().default(false),
        cookies: joi_1.default.boolean().default(false),
        html: joi_1.default.boolean().default(false),
        network: joi_1.default.boolean().default(false),
        screenshot: joi_1.default.boolean().default(false),
    }),
    elements: joi_1.default.array()
        .items(joi_1.default.object({
        selector: joi_1.default.string(),
        timeout: joi_1.default.number(),
    }))
        .required(),
    gotoOptions,
    rejectRequestPattern,
    rejectResourceTypes,
    requestInterceptors,
    setExtraHTTPHeaders,
    url: joi_1.default.string().required(),
    userAgent,
    waitFor,
});
exports.fn = joi_1.default.object().keys({
    code: joi_1.default.string().required(),
    context: joi_1.default.object(),
    detached: joi_1.default.boolean(),
});
exports.stats = joi_1.default.object().keys({
    budgets: joi_1.default.array().items(joi_1.default.object()).optional(),
    config: joi_1.default.object(),
    url: joi_1.default.string().required(),
});
//# sourceMappingURL=browserless-api.schema.js.map